@@ -10,17 +10,15 @@ from .froc_curve import generate_froc_curve, froc_point, calc_scores
 from .utils import transform_gt_into_pr
 
 
-def generate_bootstrap_curves(
-    gt_ann,
-    pr_ann,
-    n_bootstrap_samples=5,
-    use_iou=False,
-    iou_thres=0.5,
-    n_sample_points=50,
-    plot_title="Bootstrap FROC",
-    plot_output_path="froc_bootstrapped.png",
-    test_ann=None
-):
+def generate_bootstrap_curves(gt_ann,
+                              pr_ann,
+                              n_bootstrap_samples=5,
+                              use_iou=False,
+                              iou_thres=0.5,
+                              n_sample_points=50,
+                              plot_title="Bootstrap FROC",
+                              plot_output_path="froc_bootstrapped.png",
+                              test_ann=None):
     with open(gt_ann, "r") as fp:
         GT_ANN = json.load(fp)
 
@@ -88,14 +86,12 @@ def generate_bootstrap_curves(
     for cat_id in collected_frocs["lls"]:
         mean_froc_lls[cat_id] = np.mean(
             np.array(collected_frocs["lls"][cat_id]).reshape(
-                n_bootstrap_samples, n_sample_points
-            ),
+                n_bootstrap_samples, n_sample_points),
             axis=0,
         )
         mean_froc_nlls[cat_id] = np.mean(
             np.array(collected_frocs["nlls"][cat_id]).reshape(
-                n_bootstrap_samples, n_sample_points
-            ),
+                n_bootstrap_samples, n_sample_points),
             axis=0,
         )
 
@@ -103,8 +99,7 @@ def generate_bootstrap_curves(
 
     for cat_id in collected_frocs["lls"]:
         mean_froc_curve[cat_id] = np.stack(
-            (mean_froc_nlls[cat_id], mean_froc_lls[cat_id]), axis=-1
-        )
+            (mean_froc_nlls[cat_id], mean_froc_lls[cat_id]), axis=-1)
         plt.semilogx(
             mean_froc_curve[cat_id][:, 0],
             mean_froc_curve[cat_id][:, 1],
@@ -117,8 +112,12 @@ def generate_bootstrap_curves(
                 t_pr = transform_gt_into_pr(t_ann, gt_ann)
                 stats = froc_point(gt_ann, t_pr, .5, use_iou, iou_thres)
                 _lls_accuracy, _nlls_per_image = calc_scores(stats, {}, {})
-                plt.plot(_nlls_per_image[cat_id][0], _lls_accuracy[cat_id][0],
-                        '+', markersize=12, label=t_ann.split('/')[-3])
+                label = t_ann.split('/')[-1].replace('.json', '')
+                plt.plot(_nlls_per_image[cat_id][0],
+                         _lls_accuracy[cat_id][0],
+                         '+',
+                         markersize=12,
+                         label=label)
 
     plt.xlabel("FP/image")
     plt.ylabel("Sensitivity")
